package
module
Version:
v0.0.0-...-abf80d6
Opens a new window with list of versions in this module.
Published: Aug 20, 2024
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
type TOTPImpl struct {
Username string `json:username`
Password string `json:password`
TOTP string `json:totp`
Key string `json:key`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.